Trait bit_reverse::LookupReverse
[−]
[src]
pub trait LookupReverse<T> {
fn swap_bits(self) -> T;
}Computes bit reversal by using lookup table to translate a single byte into its reverse. For multi-byte types, the byte order is swapped to complete the reversal.
Required Methods
fn swap_bits(self) -> T
Swaps the bits such that bit i is now bit N-i, where N is the length of the T in bits.